package net.wanji.utc.service.systemadmin.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import net.wanji.utc.common.typeenum.ManufacturerApiInfoTypeEnum;
import net.wanji.utc.mapper.ManufacturerApiInfoMapper;
import net.wanji.utc.mapper.ManufacturerInfoMapper;
import net.wanji.utc.po.ManufacturerApiInfoPO;
import net.wanji.utc.service.systemadmin.ManufacturerApiInfoService;
import net.wanji.utc.vo.systemadmin.DeleteListInVO;
import net.wanji.utc.vo.systemadmin.ManufacturerApiInfoInsertOrUpdateInVO;
import net.wanji.utc.vo.systemadmin.ManufacturerApiInfoListInVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author Kent HAN
 * @date 2022/11/24 14:10
 */
@Service
public class ManufacturerApiInfoServiceImpl implements ManufacturerApiInfoService {
    @Autowired
    ManufacturerApiInfoMapper manufacturerApiInfoMapper;
    @Autowired
    ManufacturerInfoMapper manufacturerInfoMapper;

    @Override
    public PageInfo<ManufacturerApiInfoPO> list(ManufacturerApiInfoListInVO manufacturerApiInfoListInVO) {
        Integer pageNum = manufacturerApiInfoListInVO.getPageNum();
        Integer pageSize = manufacturerApiInfoListInVO.getPageSize();

        String name = manufacturerApiInfoListInVO.getName();

        String typeStr = manufacturerApiInfoListInVO.getTypeStr();
        Integer typeCode = null;
        if (typeStr != null) {
            typeCode = ManufacturerApiInfoTypeEnum.getCodeByMsg(typeStr);
        }

        String manufacturerNick = manufacturerApiInfoListInVO.getManufacturerNick();
        Integer manufacturerId = null;
        if (manufacturerNick != null) {
            manufacturerId = manufacturerInfoMapper.selectIdByNick(manufacturerNick);
        }

        PageHelper.startPage(pageNum, pageSize);
        List<ManufacturerApiInfoPO> manufacturerApiInfoPOList = manufacturerApiInfoMapper.selectByOptionals(
                name, typeCode, manufacturerId);
        PageInfo<ManufacturerApiInfoPO> manufacturerApiInfoPOPageInfo = new PageInfo<>(manufacturerApiInfoPOList);

        return manufacturerApiInfoPOPageInfo;
    }

    @Override
    public void insertOrUpdate(ManufacturerApiInfoInsertOrUpdateInVO inVO) {
        ManufacturerApiInfoPO manufacturerApiInfoPO = new ManufacturerApiInfoPO();
        BeanUtils.copyProperties(inVO, manufacturerApiInfoPO);
        String typeStr = inVO.getApiType();
        Integer typeCode = ManufacturerApiInfoTypeEnum.getCodeByMsg(typeStr);
        String manufacturerName = inVO.getManufacturerName();
        Integer manufacturerId = manufacturerInfoMapper.selectIdByNick(manufacturerName);
        manufacturerApiInfoPO.setType(typeCode);
        manufacturerApiInfoPO.setManufacturerId(manufacturerId);

        Integer id = inVO.getId();
        if (id == null || id == 0) {
            // 添加
            manufacturerApiInfoMapper.insertOne(manufacturerApiInfoPO);
        } else {
            // 修改
            manufacturerApiInfoMapper.updateOne(manufacturerApiInfoPO);
        }
    }

    @Override
    public void delete(DeleteListInVO inVO) {
        List<Integer> ids = inVO.getIds();
        manufacturerApiInfoMapper.deleteBatch(ids);
    }
}
